﻿/**
* @file This file contains the ResponsiveDynamic class
* @author michael.schertler@outlook.de
*/
/**
* @class
* @author michael.schertler@outlook.de
* @classdesc This class handles many responsive mechanisms
* @description Responsive layout library
*/
function ResponsiveDynamic() {
}
/**
 * @description This method sets the body font size depending on the window width, hides & displays elements and other stuff
 */
ResponsiveDynamic.resize = function () {
  var width = null;
  if (window.innerWidth) width = window.innerWidth;
  else width = document.body.clientWidth;
  if (width >= 2600) document.body.style.fontSize = "20px";
  else if (width >= 2200) document.body.style.fontSize = "18px";
  else if (width >= 1920) document.body.style.fontSize = "16px";
  else if (width >= 1400) document.body.style.fontSize = "14px";
  else if (width >= 1024) document.body.style.fontSize = "12px";
  else if (width >= 768) document.body.style.fontSize = "10px";
  else if (width >= 480) document.body.style.fontSize = "8px";
  else if (width >= 150) document.body.style.fontSize = "6px";
  else document.body.style.fontSize = "4px";
  if (width >= 1024) ResponsiveDynamic.toggleNavTexts(true);
  else ResponsiveDynamic.toggleNavTexts(false);
  if (width >= 768) document.getElementById("ModuleName").innerHTML = dynamic.moduleIdentifier["ArticleNumber"];
  else document.getElementById("ModuleName").innerHTML = dynamic.moduleIdentifier["Type"];
  if (width >= 480) ResponsiveDynamic.toggleNavMenu(true);
  else ResponsiveDynamic.toggleNavMenu(false);
  if (width >= 300) ResponsiveDynamic.toggleNavMenuText(true);
  else ResponsiveDynamic.toggleNavMenuText(false);
  var height = null;
  if (window.innerHeight) height = window.innerHeight;
  else height = document.body.clientHeight;
  if (height >= 512) {
    document.getElementById("AuthTable").parentElement.parentElement.style.top = "35%";
    document.getElementById("AuthTable").parentElement.parentElement.style.height = "30%";
  } else {
    document.getElementById("AuthTable").parentElement.parentElement.style.top = "10%";
    document.getElementById("AuthTable").parentElement.parentElement.style.height = "80%";
  }
  document.getElementById("NavMenu").style.height = new Number(0.96 * height - 5 * window.parseInt(document.body.style.fontSize, 10) - 1).toString() + "px";
  if (location.pathname.split("/")[location.pathname.split("/").length - 1].toLowerCase() == "info.htm") dynamic.setTabHeight(new Number(0.96 * height - 5 * window.parseInt(document.body.style.fontSize, 10) - 25).toString() + "px");
  else dynamic.setTabHeight(new Number(0.96 * height - 5 * window.parseInt(document.body.style.fontSize, 10) - 1).toString() + "px");
};
/**
 * @description This method hides / shows the icon texts underneath the symbols and adjusts their size
 * @param {Boolean} type Show (true) or hide (false)
 */
ResponsiveDynamic.toggleNavTexts = function (type) {
  var texts = document.getElementById("NavFrame").getElementsByTagName("DIV");
  for (var i = 0; i < texts.length; i++) {
    if (texts[i].className == "Symbols_Text") {
      if (type) texts[i].style.display = "";
      else texts[i].style.display = "none";
    }
  }
  var icons = document.getElementById("NavFrame").getElementsByTagName("OBJECT");
  for (var i = 0; i < icons.length; i++) {
    if (icons[i].parentElement.className == "Symbols_right" || icons[i].parentElement.className == "Symbols_right Marked") {
      if (type) {
        icons[i].style.width = "40%";
        icons[i].style.height = "40%";
        icons[i].children[0].style.maxWidth = "40%";
        icons[i].children[0].style.maxHeight = "40%";
      } else {
        icons[i].style.width = "70%";
        icons[i].style.height = "70%";
        icons[i].children[0].style.maxWidth = "70%";
        icons[i].children[0].style.maxHeight = "70%";
      }
    }
  }
};
/**
 * @description This method hides / shows the navigation symbols or the menu button
 * @param {Boolean} type Show (true) or hide (false)
 */
ResponsiveDynamic.toggleNavMenu = function (type) {
  var symbols = document.getElementById("NavFrame").children;
  for (var i = 0; i < symbols.length; i++) {
    if (symbols[i].className == "Symbols_right" || symbols[i].className == "Symbols_right Marked") {
      if (type) symbols[i].style.display = "";
      else symbols[i].style.display = "none";
    } else if (symbols[i].className == "Symbol_Menu") {
      if (type) symbols[i].style.display = "none";
      else symbols[i].style.display = "";
    }
  }
  if (document.getElementById("NavMenu").style.display == "" && type) document.getElementById("NavMenu").style.display = "none";
};
/**
 * @description This method shows / hides the "Menu" text next to the menu symbol
 * @param {Boolean} type Show (true) or hide (false)
 */
ResponsiveDynamic.toggleNavMenuText = function (type) {
  var elements = document.getElementById("NavFrame").getElementsByTagName("A");
  for (var i = 0; i < elements.length; i++) {
    if (elements[i].className == "Symbol_Menu") {
      if (type) elements[i].style.width = "35%";
      else elements[i].style.width = "20%";
    }
  }
  if (type) document.getElementById("NavFrame").getElementsByTagName("SPAN")[0].style.display = "";
  else document.getElementById("NavFrame").getElementsByTagName("SPAN")[0].style.display = "none";
};
/**
 * @description This method shows / hides the mobile fullscreen menu
 * @param {Boolean} type Optional, Show (true) or hide (false)
 */
ResponsiveDynamic.toggleMenu = function (type) {
};
/**
 * @description This method shows / hides navigation bar drop down elements
 * @param {Boolean} type Show (true) or hide (false)
 */
ResponsiveDynamic.toggleDropDown = function (these, type) {
  var elements = these.getElementsByTagName("DIV");
  for (var i = 0; i < elements.length; i++) {
    if (elements[i].className == "Menu_DropDown") {
      if (type) elements[i].style.display = "";
      else elements[i].style.display = "none";
    }
  }
};






/**
* @description This method shows / hides the mobile fullscreen menu drop down subelements
* @param {Boolean} type Show (true) or hide (false)
*/
ResponsiveDynamic.toggleSubElements = function (here) {
  var elements = document.getElementById("NavMenu").getElementsByTagName("DIV")[here].getElementsByTagName("A");
  for (var i = 0; i < elements.length; i++) {
    if (elements[i].className == "Menu_SubEntry") {
      if (elements[i].style.display == "") elements[i].style.display = "none";
      else elements[i].style.display = "";
    }
  }
  if (elements[0].innerHTML.substr(elements[0].innerHTML.length - 1) == "\u25B2") elements[0].innerHTML = elements[0].innerHTML.substring(0, elements[0].innerHTML.length - 1) + "\u25BC";
  else elements[0].innerHTML = elements[0].innerHTML.substring(0, elements[0].innerHTML.length - 1) + "\u25B2";
};